@@ -4,6 +4,9 @@
 from .api import (
     set_default,
     search,
+    search_movie,
+    search_episode,
+    search_series,
     get,
     title,
     imdbid,
